@@ -68,7 +68,7 @@ class VoronoiTess(object):
                 points.
         """
         self.points = list(points)
-        dim = map(len, self.points)
+        dim = [len(i) for i in self.points]
         if max(dim) != min(dim):
             raise ValueError("Input points must all have the same dimension!")
         self.dim = dim[0]
@@ -78,16 +78,16 @@ class VoronoiTess(object):
                 self.points.append(coord)
         output = qvoronoi("o Fv", self.points)
         output.pop(0)
-        nvertices, nregions, i = map(int, output.pop(0).split())
-        self.vertices = [map(float, output.pop(0).split())
-                         for i in xrange(nvertices)]
-        self.regions = [map(int, output.pop(0).split()[1:])
-                        for i in xrange(nregions)]
+        nvertices, nregions, i = [int(i) for i in output.pop(0).split()]
+        self.vertices = [[float(j) for j in output.pop(0).split()]
+                         for i in range(nvertices)]
+        self.regions = [[int(j) for j in output.pop(0).split()[1:]]
+                        for i in range(nregions)]
 
         output.pop(0)
         ridges = {}
         for line in output:
-            val = map(int, line.split())
+            val = [int(i) for i in line.split()]
             ridges[tuple(val[1:3])] = val[3:]
         self.ridges = ridges
 
