@@ -63,23 +63,30 @@ int isatty(int);  /* returns 1 if stdin is a tty
 char hidden_options[]=" d v H Qbb Qf Qg Qm Qr Qu Qv Qx Qz TR E V Fp Gt Q0 Q1 Q2 Q3 Q4 Q5 Q6 Q7 Q8 Q9 ";
 char qhalf_hidden_options[]=" d n v Qbb QbB Qf Qg Qm Qr QR Qv Qx Qz TR E V Fa FA FC FD FS Ft FV Gt Q0 Q1 Q2 Q3 Q4 Q5 Q6 Q7 Q8 Q9 ";
 
-__attribute__((visibility("default"))) static PyObject* py_qconvex(PyObject *self, PyObject *args) {
+static PyObject* py_qconvex(PyObject *self, PyObject *args) {
     const char *arg;
     const char *data;
     int curlong, totlong; /* used !qh_NOmem */
     int exitcode, numpoints, dim;
     coordT *points;
     boolT ismalloc;
-    if (!PyArg_ParseTuple(args, "ss", &arg, &data))
-        return NULL;
     char* argv[10];
     int argc = 1;
     char *rest;
     char *token;
     /* Defensively copy the string first */
     char tempstr[30];
+    char* ptr;
+    char *bp;
+    size_t size;
+    FILE* fin;
+    FILE* fout;
+
+    if (!PyArg_ParseTuple(args, "ss", &arg, &data))
+        return NULL;
+
     strcpy(tempstr, arg);
-    char* ptr = tempstr;
+    ptr = tempstr;
 
     while(token = strtok_r(ptr, " ", &rest)) {
         argv[argc] = token;
@@ -88,13 +95,10 @@ __attribute__((visibility("default"))) static PyObject* py_qconvex(PyObject *sel
     }
     argv[0] = "qconvex";
 
-    char *bp;
-    size_t size;
-
     /* Because qhull uses stdin and stdout streams for io, we need to create
     FILE* stream to simulate these io streams.*/
-    FILE* fin = fmemopen(data, strlen(data), "r");
-    FILE* fout = open_memstream(&bp, &size);
+    fin = fmemopen(data, strlen(data), "r");
+    fout = open_memstream(&bp, &size);
 
     if ((fin != NULL) && (fout != NULL))
     {
@@ -137,23 +141,30 @@ __attribute__((visibility("default"))) static PyObject* py_qconvex(PyObject *sel
     }
 }
 
-__attribute__((visibility("default"))) static PyObject* py_qdelaunay(PyObject *self, PyObject *args) {
+
+static PyObject* py_qdelaunay(PyObject *self, PyObject *args) {
     const char *arg;
     const char *data;
     int curlong, totlong; /* used !qh_NOmem */
     int exitcode, numpoints, dim;
     coordT *points;
     boolT ismalloc;
-    if (!PyArg_ParseTuple(args, "ss", &arg, &data))
-        return NULL;
     char* argv[10];
     int argc = 1;
     char *rest;
     char *token;
     /* Defensively copy the string first */
     char tempstr[30];
+    char* ptr;
+    char *bp;
+    size_t size;
+    FILE* fin;
+    FILE* fout;
+
+    if (!PyArg_ParseTuple(args, "ss", &arg, &data))
+        return NULL;
     strcpy(tempstr, arg);
-    char* ptr = tempstr;
+    ptr = tempstr;
 
     while(token = strtok_r(ptr, " ", &rest)) {
         argv[argc] = token;
@@ -162,13 +173,12 @@ __attribute__((visibility("default"))) static PyObject* py_qdelaunay(PyObject *s
     }
 
     argv[0] = "qdelaunay";
-    char *bp;
-    size_t size;
+
 
     /* Because qhull uses stdin and stdout streams for io, we need to create
     FILE* stream to simulate these io streams.*/
-    FILE* fin = fmemopen(data, strlen(data), "r");
-    FILE* fout = open_memstream(&bp, &size);
+    fin = fmemopen(data, strlen(data), "r");
+    fout = open_memstream(&bp, &size);
 
     if ((fin != NULL) && (fout != NULL))
     {
@@ -217,23 +227,29 @@ __attribute__((visibility("default"))) static PyObject* py_qdelaunay(PyObject *s
 }
 
 
-__attribute__((visibility("default"))) static PyObject* py_qvoronoi(PyObject *self, PyObject *args) {
+static PyObject* py_qvoronoi(PyObject *self, PyObject *args) {
     const char *arg;
     const char *data;
     int curlong, totlong; /* used !qh_NOmem */
     int exitcode, numpoints, dim;
-    coordT *points;
-    boolT ismalloc;
-    if (!PyArg_ParseTuple(args, "ss", &arg, &data))
-        return NULL;
     char *argv[10];
     int argc = 1;
     char *rest;
     char *token;
-    /* Defensively copy the string first */
     char tempstr[30];
+    char* ptr;
+    coordT *points;
+    boolT ismalloc;
+    char *bp;
+    FILE* fin;
+    FILE* fout;
+
+    if (!PyArg_ParseTuple(args, "ss", &arg, &data))
+        return NULL;
+
+    /* Defensively copy the string first */
     strcpy(tempstr, arg);
-    char* ptr = tempstr;
+    ptr = tempstr;
 
     while(token = strtok_r(ptr, " ", &rest)) {
         argv[argc] = token;
@@ -242,13 +258,12 @@ __attribute__((visibility("default"))) static PyObject* py_qvoronoi(PyObject *se
     }
     argv[0] = "qvoronoi";
 
-    char *bp;
     size_t size;
 
     /* Because qhull uses stdin and stdout streams for io, we need to create
     FILE* stream to simulate these io streams.*/
-    FILE* fin = fmemopen(data, strlen(data), "r");
-    FILE* fout = open_memstream(&bp, &size);
+    fin = fmemopen(data, strlen(data), "r");
+    fout = open_memstream(&bp, &size);
 
     if ((fin != NULL) && (fout != NULL))
     {
@@ -296,23 +311,30 @@ __attribute__((visibility("default"))) static PyObject* py_qvoronoi(PyObject *se
     }
 }
 
-__attribute__((visibility("default"))) static PyObject* py_qhalf(PyObject *self, PyObject *args) {
+
+static PyObject* py_qhalf(PyObject *self, PyObject *args) {
     const char *arg;
     const char *data;
     int curlong, totlong; /* used !qh_NOmem */
     int exitcode, numpoints, dim;
     coordT *points;
     boolT ismalloc;
-    if (!PyArg_ParseTuple(args, "ss", &arg, &data))
-        return NULL;
     char *argv[10];
     int argc = 1;
     char *rest;
     char *token;
     /* Defensively copy the string first */
     char tempstr[30];
-    strcpy(tempstr, arg);
     char* ptr = tempstr;
+    char *bp;
+    size_t size;
+    FILE* fin;
+    FILE* fout;
+
+    if (!PyArg_ParseTuple(args, "ss", &arg, &data))
+        return NULL;
+
+    strcpy(tempstr, arg);
 
     while(token = strtok_r(ptr, " ", &rest)) {
         argv[argc] = token;
@@ -321,13 +343,10 @@ __attribute__((visibility("default"))) static PyObject* py_qhalf(PyObject *self,
     }
     argv[0] = "qhalf";
 
-    char *bp;
-    size_t size;
-
     /* Because qhull uses stdin and stdout streams for io, we need to create
      FILE* stream to simulate these io streams.*/
-    FILE* fin = fmemopen(data, strlen(data), "r");
-    FILE* fout = open_memstream(&bp, &size);
+    fin = fmemopen(data, strlen(data), "r");
+    fout = open_memstream(&bp, &size);
 
     if ((fin != NULL) && (fout != NULL))
     {
@@ -380,7 +399,7 @@ __attribute__((visibility("default"))) static PyObject* py_qhalf(PyObject *self,
 }
 
 
-__attribute__((visibility("default"))) static PyMethodDef QhullMethods[] = {
+static PyMethodDef QhullMethods[] = {
     {"qconvex", py_qconvex, METH_VARARGS, "qconvex"},
     {"qdelaunay", py_qdelaunay, METH_VARARGS, "qdelaunay"},
     {"qvoronoi", py_qvoronoi, METH_VARARGS, "qvoronoi"},
@@ -400,13 +419,6 @@ struct module_state {
 static struct module_state _state;
 #endif
 
-static PyObject *
-error_out(PyObject *m) {
-    struct module_state *st = GETSTATE(m);
-    PyErr_SetString(st->error, "something bad happened");
-    return NULL;
-}
-
 #if PY_MAJOR_VERSION >= 3
 
 static int _pyhull_traverse(PyObject *m, visitproc visit, void *arg) {
